@@ -19,12 +19,12 @@ def _hrv_get_rri(peaks=None, sampling_rate=1000, interpolate=False, **kwargs):
             sampling_rate = 10
 
         # Compute length of interpolated heart period signal at requested sampling rate.
-        desired_length = int(np.rint(peaks[-1] / sampling_rate * sampling_rate))
+        desired_length = int(np.rint(peaks[-1]))
 
         rri = signal_interpolate(
             peaks[1:],  # Skip first peak since it has no corresponding element in heart_period
             rri,
-            desired_length=desired_length,
+            x_new=np.arange(desired_length),
             **kwargs
         )
         return rri, sampling_rate
